"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/minio.ts
var minio_exports = {};
__export(minio_exports, {
  createServerMinioClient: () => createServerMinioClient
});
module.exports = __toCommonJS(minio_exports);
var import_minio = require("minio");

// src/helpers/client-options.schema.ts
var import_validation = require("@settlemint/sdk-utils/validation");
var import_zod = require("zod");
var ClientOptionsSchema = import_zod.z.object({
  /** The URL of the MinIO instance to connect to */
  instance: import_validation.UrlSchema
});
var ServerClientOptionsSchema = import_zod.z.object({
  /** The URL of the MinIO instance to connect to */
  instance: import_validation.UrlSchema,
  /** The MinIO access key used to authenticate with the MinIO server */
  accessKey: import_zod.z.string(),
  /** The MinIO secret key used to authenticate with the MinIO server */
  secretKey: import_zod.z.string()
});

// src/helpers/runtime.ts
function ensureServer() {
  if (typeof window !== "undefined") {
    throw new Error("This function can only be called on the server.");
  }
}

// src/helpers/schema.ts
var import_zod2 = require("zod");
var t = {
  String: (options = {}) => {
    let schema = import_zod2.z.string();
    if (options.format === "date-time") {
      schema = schema.datetime();
    } else if (options.format === "uri") {
      schema = schema.url();
    }
    return schema;
  },
  Number: () => {
    return import_zod2.z.number();
  },
  Boolean: () => {
    return import_zod2.z.boolean();
  },
  Object: (shape, options = {}) => {
    return import_zod2.z.object(shape);
  },
  Array: (items) => {
    return import_zod2.z.array(items);
  },
  Optional: (schema) => {
    return schema.optional();
  }
};
function validate(schema, value) {
  return schema.parse(value);
}
var FileMetadataSchema = t.Object(
  {
    id: t.String(),
    name: t.String(),
    contentType: t.String(),
    size: t.Number(),
    uploadedAt: t.String({ format: "date-time" }),
    etag: t.String(),
    url: t.Optional(t.String({ format: "uri" }))
  },
  { $id: "FileMetadata" }
);

// src/minio.ts
function createServerMinioClient(options) {
  ensureServer();
  const validatedOptions = validate(ServerClientOptionsSchema, options);
  const url = new URL(validatedOptions.instance);
  return {
    client: new import_minio.Client({
      endPoint: url.hostname,
      accessKey: validatedOptions.accessKey,
      secretKey: validatedOptions.secretKey,
      useSSL: url.protocol !== "http:",
      port: url.port ? Number(url.port) : void 0,
      region: "eu-central-1"
    })
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  createServerMinioClient
});
//# sourceMappingURL=minio.cjs.map